==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/WebFilteringExpressionsTreeOrFilteringExpressionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebFilteringExpressionsTreeOrFilteringExpressionDescription } from "./WebFilteringExpressionsTreeOrFilteringExpressionDescription";
/**
 * @hidden
 */
var WebFilteringExpressionsTreeOrFilteringExpressionDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebFilteringExpressionsTreeOrFilteringExpressionDescriptionMetadata, _super);
    function WebFilteringExpressionsTreeOrFilteringExpressionDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebFilteringExpressionsTreeOrFilteringExpressionDescriptionMetadata.b = function (a) {
        if (WebFilteringExpressionsTreeOrFilteringExpressionDescriptionMetadata.a == null) {
            WebFilteringExpressionsTreeOrFilteringExpressionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebFilteringExpressionsTreeOrFilteringExpressionDescriptionMetadata.c(WebFilteringExpressionsTreeOrFilteringExpressionDescriptionMetadata.a);
        }
        if (a.j(WebFilteringExpressionsTreeOrFilteringExpressionDescriptionMetadata.a)) {
            return;
        }
        a.y(WebFilteringExpressionsTreeOrFilteringExpressionDescriptionMetadata.a);
    };
    WebFilteringExpressionsTreeOrFilteringExpressionDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:FilteringExpressionsTreeOrFilteringExpression");
    };
    WebFilteringExpressionsTreeOrFilteringExpressionDescriptionMetadata.d = function (a) {
        WebFilteringExpressionsTreeOrFilteringExpressionDescriptionMetadata.b(a);
        a.aa("WebFilteringExpressionsTreeOrFilteringExpression", function () { return new WebFilteringExpressionsTreeOrFilteringExpressionDescription(); });
        a.z("WebFilteringExpressionsTreeOrFilteringExpression", WebFilteringExpressionsTreeOrFilteringExpressionDescriptionMetadata.a);
    };
    WebFilteringExpressionsTreeOrFilteringExpressionDescriptionMetadata.$t = markType(WebFilteringExpressionsTreeOrFilteringExpressionDescriptionMetadata, 'WebFilteringExpressionsTreeOrFilteringExpressionDescriptionMetadata');
    WebFilteringExpressionsTreeOrFilteringExpressionDescriptionMetadata.a = null;
    return WebFilteringExpressionsTreeOrFilteringExpressionDescriptionMetadata;
}(Base));
export { WebFilteringExpressionsTreeOrFilteringExpressionDescriptionMetadata };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/WebFilteringExpressionsTreeOrFilteringExpressionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebFilteringExpressionsTreeOrFilteringExpressionDescription } from "./WebFilteringExpressionsTreeOrFilteringExpressionDescription";
/**
 * @hidden
 */
var WebFilteringExpressionsTreeOrFilteringExpressionDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebFilteringExpressionsTreeOrFilteringExpressionDescriptionMetadata, _super);
    function WebFilteringExpressionsTreeOrFilteringExpressionDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebFilteringExpressionsTreeOrFilteringExpressionDescriptionMetadata.b = function (a) {
        if (WebFilteringExpressionsTreeOrFilteringExpressionDescriptionMetadata.a == null) {
            WebFilteringExpressionsTreeOrFilteringExpressionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebFilteringExpressionsTreeOrFilteringExpressionDescriptionMetadata.c(WebFilteringExpressionsTreeOrFilteringExpressionDescriptionMetadata.a);
        }
        if (a.k(WebFilteringExpressionsTreeOrFilteringExpressionDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebFilteringExpressionsTreeOrFilteringExpressionDescriptionMetadata.a);
    };
    WebFilteringExpressionsTreeOrFilteringExpressionDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:FilteringExpressionsTreeOrFilteringExpression");
    };
    WebFilteringExpressionsTreeOrFilteringExpressionDescriptionMetadata.d = function (a) {
        WebFilteringExpressionsTreeOrFilteringExpressionDescriptionMetadata.b(a);
        a.ac("WebFilteringExpressionsTreeOrFilteringExpression", function () { return new WebFilteringExpressionsTreeOrFilteringExpressionDescription(); });
        a.ab("WebFilteringExpressionsTreeOrFilteringExpression", WebFilteringExpressionsTreeOrFilteringExpressionDescriptionMetadata.a);
    };
    WebFilteringExpressionsTreeOrFilteringExpressionDescriptionMetadata.$t = markType(WebFilteringExpressionsTreeOrFilteringExpressionDescriptionMetadata, 'WebFilteringExpressionsTreeOrFilteringExpressionDescriptionMetadata');
    WebFilteringExpressionsTreeOrFilteringExpressionDescriptionMetadata.a = null;
    return WebFilteringExpressionsTreeOrFilteringExpressionDescriptionMetadata;
}(Base));
export { WebFilteringExpressionsTreeOrFilteringExpressionDescriptionMetadata };
